pendant package
===============

``aws`` Submodule
-----------------

.. toctree::

    pendant.aws
    pendant.aws.batch
    pendant.aws.exception
    pendant.aws.logs
    pendant.aws.response
    pendant.aws.s3

``util`` Submodule
------------------

.. toctree::

   pendant.util
